# 2D Beginner Project

This project is made to support the new Beginner tutorial for 2D.

Head over to the [wiki](https://gitlab.internal.unity3d.com/content-team/2DBeginnerProject/wikis/home)
to get relevant documentation.

## Contributing

## Share your plans (Register)

Project templates will be available to our user through the Hub, and organized by categories _(2d, 3d, xv, ...)_. In that sense, the purpose, name, category, and content of your template should first be discussed with the Production Management team, so that this information can be properly curated to match Unity's strategy.  Please contact ** @daniel.tg ** on _slack_ to start this conversation.

Once Product Management has weighed in on your plans, please take a few minutes to [register your template using this page](https://docs.google.com/spreadsheets/d/11gxvpUZRDIFDmTxNqRwGirpncTecl7cchumR0H6BGqw/edit?usp=sharing) with your project template information. Simply add a new row to the table and fill in the required information.

This will help inform Product, Project, Release and Documentation Teams to coordinate between dependencies. It also allows shared awareness for the whole organization.
We then can also track it in our directory listing.

## Project template Development Structure

The project template is a project itself, so it should be very straightforward to develop with.

```none
<Project Root>
 │
 ├── README.md
 ├── Assets
 │       ├─ Scenes
 │       │     └── SampleScene.unity
 │       └─ Tests
 │            ├── Editor
 │                     └── EditorExampleTest.cs
 │            └── Runtime
 │                      ├── RuntimeTests.asmdef
 │                      └── RuntimeExampleTest.cs
 ├── ProjectSettings
 └── Packages
         ├─ manifest.json
         └─ com.unity.template.mytemplate
                   ├── package.json
                   ├── CHANGELOG
                   ├── LICENSE
                   ├── Documentation~
                   ├── Third Party Notices.md
                   └── QAReport.md
```

## Develop your project template

The project template is a Unity Editor project itself, as such, it should be very straightforward to develop with. Here's how to set it up:

1. ##### Fork the `project-template-starter-kit` repository

    Forking a repository is a simple two-step process.
    - On Gitlab, head over to the [project-template-starter-kit](https://gitlab.cds.internal.unity3d.com/upm-packages/project-templates/project-template-starter-kit) repository.  If you don't have access, you can request it in the **#devs-templates** slack channel.
    - Click on the **Fork** button at the top-left corner of the page, and follow the instructions to fork the starter kit template into the `project-templates` sub-group.

    That's it! You now have your own copy (fork) of the original `project-template-starter-kit` repository you can use to develop your project template.

1. ##### Clone your project template repository for local development

    In a console application, go to the a folder where you want to create your project folder, then clone your newly forked repository.

    ```none
    git clone git@gitlab.cds.internal.unity3d.com:upm-packages/project-templates/<your-project-template-name>.git
    ```

1. ##### Rename the project template package

    Rename the folder `Package/com.unity.template.mytemplate` by replacing `mytemplate` with your own project template's name.
    This will be the package used to define your project template when publishing.

    You may be wondering why we include `com.unity.template.mytemplate` in the project's packages. This package will describe your project template to our users, and will be form the package when publishing your template. It will not be included in projects our users create from your template, but will be referenced so users can access template information such as documentation or license information.

1. ##### Fill in your project template's package information

	Update the following required fields in `Packages/com.unity.template.mytemplate/package.json`:
	- `name`: Project template's package name, it should follow this naming convention: `com.unity.template.[your-template-name]`
    (Example: `com.unity.template.3d`
	- `displayName`: Package user friendly display name. (Example: `"First person shooter"`). <br>__Note:__ Use a display name that will help users understand what your project template is intended for.
	- `version`: Package version `X.Y.Z`, your project **must** adhere to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).
	- `unity`: Unity Version your project template is compatible with. (Example: `2018.3`)
	- `description`: This is the description for your template which will be displayed to the user to let them know what this template is for. This description shouldn't include anything version-specific and should stay pretty consistent across template versions.
	- `dependencies`: Leave this field a blank object `{}` since it will get filled by the CI system by copying the dependencies from the project's `manifest.json`. Therefore if you need to add package dependencies for your template, add them in the `dependencies` section of your `manifest.json`.

1. ##### Update **README.md**

    The README.md file should contain all pertinent information for template developers, such as:
	* Prerequisites
	* External tools or development libraries
	* Required installed Software

1. ##### Prepare your documentation

    Rename and update **Packages/com.unity.template.mytemplate/Documentation~/your-package-name.md** documentation file.

    Use this documentation template to create preliminary, high-level documentation for the _development_ of your template's package. This document is meant to introduce other developers to the features and sample files included in your project template.

    Your template's documentation will be made available online and in the editor during publishing to guide our users.

1. ##### Update the changelog   

    **Packages/com.unity.template.mytemplate/CHANGELOG.md**.

	Every new feature or bug fix should have a trace in this file. For more details on the chosen changelog format, see [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).

	Changelogs will be made available online to inform users about the changes they can expect when downloading a project template.  As a consequence, the changelog content should be customer friendly and present clear, meaningful information.

1. ##### Open your cloned project and develop!

    Start **Unity**, open the previously forked template project folder. Once opened, you can modify the project settings, the project assets and even the packages dependencies in the `Packages/manifest.json` to suit your needs. Your project template will contain all the content of you project.

## Create a Preview

All initial versions of templates should first be tagged as `preview`.  This indicates to our users that the template is a work in progress or newly created.  Preview templates will be discoverable through the HUB, and will be clearly marked as **Preview** to set the proper expectations. Once the template has been in use for a while by users, and vetted by Unity's Release QA team, its `preview` tag can then be removed, and the template can join the ranks of official Unity templates.

**Preview**  -  ex: `"version" : "1.2.0-preview"`

See [Package Lifecycle](http://internaldocs.hq.unity3d.com/packages_docs/lifecycle/) for requirements and suggestions.

## Make sure your project template meets all legal requirements

All templates are *required* to COMPLETE AND SUBMIT [THIS FORM](https://docs.google.com/forms/d/e/1FAIpQLSe3H6PARLPIkWVjdB_zMvuIuIVtrqNiGlEt1yshkMCmCMirvA/viewform) to receive approval. It is a simple, streamlined form that tells legal if there are any potential issues that need to be addressed prior to publication.

##### Update **Third Party Notices.md**

1. If your template includes third-party elements and its licenses are approved, then all the licenses must be added to the `Third Party Notices.md` file. Simply duplicate the `Component Name/License Type/Provide License Details` section if you have more then one licenes.

    a. Concerning `[Provide License Details]` in the `Third Party Notices.md`, a URL can work as long as it actually points to the reproduced license and the copyright information _(if applicable)_.

1. If your package does not have third party elements, you can remove the `Third Party Notices.md` file from your package.

## Adding tests to your template

Tests you add to your template package will be automatically run in Katana to ensure your template continues to work as expected as the editor's codebase evolves, it is therefore important to invest in a good set of test

You can add tests for your template in the project's `Assets/Tests` folder as you would any normal Unity project. It is advisable to also test your template's integrity so that frequent developers use doesn't change desirable static properties.

You can run the tests in the Unity test runner.

## Trying out your template locally.

If you want to test your template locally from a user's perspective, you will need to make it available to Unity. This can be accomplished by following these steps:

1. Package your project template

    It is necessary to package your template to make it available to Unity, since you cannot simply copy your current package template development project.

    We include a `build` script that can easily do this. The script is used in Gitlab CI pipelines and can be used locally. You can package your project template locally through the following command: 

    ```
    ./build.sh template-ci pack
    ```
    or on Windows machines
    ```
    build.bat template-ci pack
    ```

    This will output a `com.unity.template.<your-template-name>-0.1.0-preview.1.tgz` file in your project's folder.

    You need to make sure you have `Node.js` and `npm` _(install it from [here](https://nodejs.org/en/))_ installed on your machine to package successfully, as the script calls `npm` under the hood for packaging and publishing. The script is tested with `node@v6.10.0` and `npm@3.10.10`.

    Additionally, you need to make sure you have internet access when you use the `build` script for the first time, as the script will download and install the dependant `Node.js` package that's used under the hood.

    You cannot directly use `npm pack`, as the project template folder structure is different from the package folder structure.

1. Include the project template package in Unity editor

    You can then copy the project template's `tgz` package file in Unity in one of these paths to make it available in the editor when creating new projects:

    1. Mac: `<Unity Editor Root>/Contents/Resources/PackageManager/ProjectTemplates`

    1. Windows: `<Unity Editor Root>/Data/Resources/PackageManager/ProjectTemplates`

1. Preview your project template

    The result when creating a new project should be something like this when using the Unity Hub:

    ![Template in new project](Packages/com.unity.template.mytemplate/Documentation~/images/template_in_new_project.png)

    If you are launching the Unity editor without the hub, you will not see additional templates in the list.

## Publishing your template for use in the Editor

The first step to get your package published to production for public consumption is to send it to the staging repository, where it can be evaluated by QA and Release Management.  You can publish your template to the staging repository through Gitlab CI pipelines, which is the **recommended** approach.

1. Before you can publish through Gitlab CI, you need to go to the Gitlab page for your repository, and add your bintray `USER_NAME` and `API_KEY` in `Settings -> CI / CD -> Secret variables`.  If you don't have a bintray user name, you can request it on the ** #devs-templates ** slack channel

    ![Template in new project](Packages/com.unity.template.mytemplate/Documentation~/images/gitlab_ci_secret_variables.png)

1. Once you are ready to publish a new version, say version `1.0.0-preview`, you can add a git tag `v1.0.0-preview` to the commit you want to publish. The Gitlab CI pipelines will validate and then publish your project template to `staging`.

1. Request that your template package be published to production by [filling out the following form](https://docs.google.com/forms/d/e/1FAIpQLSeEOeWszG7F5mx_VEYm8SrjcIajxa5WoLXh-yhLvw8odsEnaQ/viewform)

1. Once your template is published to production, the last step is to create the Ono PR to include your template with a Unity Release, and have it be discovered in the Hub.  To do so, create a branch that includes your template in ** External/PackageManager/Editor/editor_installer.json **

**Note:** You can retrieve a version of your template package as an artifact from Gitlab CI pipelines following any pull request made to your repository.  This will allow you to easily test a change at any point during your development.

Follow these steps to achieve this:

  1. Go into the gitlab repository page of your project template.
  1. In the sub menu of `CI/CD`, click on `Pipelines`.
  1. Click on the cloud icon on the right side of any pipeline to download the `tgz` package file.

      ![Pipelines](Packages/com.unity.template.mytemplate/Documentation~/images/gitlab_pipeline_download.png)

## FAQ

#### Can I inherit another package template?

You cannot inherit from another package template. You can however use another package template as a starting point to create a new one.

## References

[Gitlab Project Template Group](https://gitlab.cds.internal.unity3d.com/upm-packages/project-templates).
